@@ -50,6 +50,7 @@
 #include "SessionController.h"
 #include "ProfileList.h"
 #include "Session.h"
+#include "ViewContainer.h"
 #include "ViewManager.h"
 #include "SessionManager.h"
 #include "ProfileManager.h"
@@ -109,13 +110,10 @@ MainWindow::MainWindow() :
 
     connect(_viewManager, &Konsole::ViewManager::updateWindowIcon, this,
             &Konsole::MainWindow::updateWindowIcon);
-    connect(_viewManager,
-            static_cast<void (ViewManager::*)(Profile::Ptr)>(&Konsole::ViewManager::newViewRequest),
-            this,
-            &Konsole::MainWindow::newFromProfile);
-    connect(_viewManager,
-            static_cast<void (ViewManager::*)()>(&Konsole::ViewManager::newViewRequest), this,
-            &Konsole::MainWindow::newTab);
+    connect(_viewManager, &Konsole::ViewManager::newViewWithProfileRequest,
+            this, &Konsole::MainWindow::newFromProfile);
+    connect(_viewManager, &Konsole::ViewManager::newViewRequest,
+            this, &Konsole::MainWindow::newTab);
     connect(_viewManager, &Konsole::ViewManager::viewDetached, this,
             &Konsole::MainWindow::viewDetached);
 
@@ -136,7 +134,7 @@ MainWindow::MainWindow() :
     // emulator (as they are reserved for use by terminal applications)
     correctStandardShortcuts();
 
-    setProfileList(new ProfileList(true, this));
+    setProfileList(new ProfileList(false, this));
 
     // this must come at the end
     applyKonsoleSettings();
@@ -236,6 +234,9 @@ void MainWindow::disconnectController(SessionController *controller)
 
 void MainWindow::activeViewChanged(SessionController *controller)
 {
+    if (!SessionManager::instance()->sessionProfile(controller->session())) {
+        return;
+    }
     // associate bookmark menu with current session
     bookmarkHandler()->setActiveView(controller);
     disconnect(bookmarkHandler(), &Konsole::BookmarkHandler::openUrl, nullptr, nullptr);
@@ -296,11 +297,7 @@ void MainWindow::updateWindowCaption()
         !userTitle.isEmpty() ? caption = userTitle : caption = QStringLiteral(" ");
     }
 
-    if (KonsoleSettings::showAppNameOnTitleBar()) {
-        setCaption(caption);
-    } else {
-        setPlainCaption(caption);
-    }
+    setCaption(caption);
 }
 
 void MainWindow::updateWindowIcon()
@@ -320,7 +317,8 @@ void MainWindow::setupActions()
     collection->setDefaultShortcut(_newTabMenuAction, Konsole::ACCEL + Qt::SHIFT + Qt::Key_T);
     collection->setShortcutsConfigurable(_newTabMenuAction, true);
     _newTabMenuAction->setAutoRepeat(false);
-    connect(_newTabMenuAction, &KActionMenu::triggered, this, &Konsole::MainWindow::newTab);
+    connect(_newTabMenuAction, &KActionMenu::triggered,
+            this, [this] { newTab(_viewManager->activeContainer());});
     collection->addAction(QStringLiteral("new-tab"), _newTabMenuAction);
     collection->setShortcutsConfigurable(_newTabMenuAction, true);
 
@@ -394,7 +392,7 @@ void MainWindow::setProfileList(ProfileList *list)
     profileListChanged(list->actions());
 
     connect(list, &Konsole::ProfileList::profileSelected, this,
-            &Konsole::MainWindow::newFromProfile);
+            [this](const Profile::Ptr &profile) { newFromProfile(_viewManager->activeContainer(), profile);});
 
     connect(list, &Konsole::ProfileList::actionsChanged, this,
             &Konsole::MainWindow::profileListChanged);
@@ -461,19 +459,19 @@ void MainWindow::openUrls(const QList<QUrl> &urls)
 {
     Profile::Ptr defaultProfile = ProfileManager::instance()->defaultProfile();
 
-    Q_FOREACH (const auto &url, urls) {
+    for (const auto &url : urls) {
         if (url.isLocalFile()) {
-            createSession(defaultProfile, url.path());
+            createSession(_viewManager->activeContainer(), defaultProfile, url.path());
         } else if (url.scheme() == QLatin1String("ssh")) {
-            createSSHSession(defaultProfile, url);
+            createSSHSession(_viewManager->activeContainer(), defaultProfile, url);
         }
     }
 }
 
-void MainWindow::newTab()
+void MainWindow::newTab(TabbedViewContainer *tabWidget)
 {
     Profile::Ptr defaultProfile = ProfileManager::instance()->defaultProfile();
-    createSession(defaultProfile, activeSessionDir());
+    createSession(tabWidget, defaultProfile, activeSessionDir());
 }
 
 void MainWindow::cloneTab()
@@ -483,15 +481,15 @@ void MainWindow::cloneTab()
     Session *session = _pluggedController->session();
     Profile::Ptr profile = SessionManager::instance()->sessionProfile(session);
     if (profile) {
-        createSession(profile, activeSessionDir());
+        createSession(_viewManager->activeContainer(), profile, activeSessionDir());
     } else {
         // something must be wrong: every session should be associated with profile
         Q_ASSERT(false);
-        newTab();
+        newTab(_viewManager->activeContainer());
     }
 }
 
-Session *MainWindow::createSession(Profile::Ptr profile, const QString &directory)
+Session *MainWindow::createSession(TabbedViewContainer *tabWidget, Profile::Ptr profile, const QString &directory)
 {
     if (!profile) {
         profile = ProfileManager::instance()->defaultProfile();
@@ -509,12 +507,12 @@ Session *MainWindow::createSession(Profile::Ptr profile, const QString &director
     // doesn't suffer a change in terminal size right after the session
     // starts.  Some applications such as GNU Screen and Midnight Commander
     // don't like this happening
-    _viewManager->createView(session);
+    _viewManager->createView(tabWidget, session);
 
     return session;
 }
 
-Session *MainWindow::createSSHSession(Profile::Ptr profile, const QUrl &url)
+Session *MainWindow::createSSHSession(TabbedViewContainer *tabWidget, Profile::Ptr profile, const QUrl &url)
 {
     if (!profile) {
         profile = ProfileManager::instance()->defaultProfile();
@@ -539,7 +537,7 @@ Session *MainWindow::createSSHSession(Profile::Ptr profile, const QUrl &url)
     // doesn't suffer a change in terminal size right after the session
     // starts.  some applications such as GNU Screen and Midnight Commander
     // don't like this happening
-    _viewManager->createView(session);
+    _viewManager->createView(tabWidget, session);
 
     return session;
 }
@@ -603,7 +601,7 @@ bool MainWindow::queryClose()
     }
     int result;
 
-    if (processesRunning.count() > 0) {
+    if (!processesRunning.isEmpty()) {
         result = KMessageBox::warningYesNoCancelList(this,
                                                      i18ncp("@info",
                                                             "There is a process running in this window. "
@@ -713,9 +711,9 @@ void MainWindow::showShortcutsDialog()
     }
 }
 
-void MainWindow::newFromProfile(Profile::Ptr profile)
+void MainWindow::newFromProfile(TabbedViewContainer *tabWidget, const Profile::Ptr &profile)
 {
-    createSession(profile, activeSessionDir());
+    createSession(tabWidget, profile, activeSessionDir());
 }
 
 void MainWindow::showManageProfilesDialog()
@@ -763,7 +761,7 @@ void MainWindow::showSettingsDialog(const bool showProfilePage)
 void MainWindow::applyKonsoleSettings()
 {
     setMenuBarInitialVisibility(KonsoleSettings::showMenuBarByDefault());
-
+    setRemoveWindowTitleBarAndFrame(KonsoleSettings::removeWindowTitleBarAndFrame());
     if (KonsoleSettings::allowMenuAccelerators()) {
         restoreMenuAccelerators();
     } else {
@@ -817,6 +815,23 @@ void MainWindow::setMenuBarInitialVisibility(bool visible)
     _menuBarInitialVisibility = visible;
 }
 
+void MainWindow::setRemoveWindowTitleBarAndFrame(bool frameless)
+{
+    // This is used to check if the window is in "opening" state
+    // And avoid the visibility change when we change the window flag
+    bool oldVisibility = isVisible();
+
+    if (frameless) {
+        setWindowFlags(Qt::FramelessWindowHint);
+    } else {
+        setWindowFlags(Qt::Widget);
+    }
+
+    if (oldVisibility && !isVisible()) {
+        setVisible(true);
+    }
+}
+
 void MainWindow::showEvent(QShowEvent *event)
 {
     // Make sure the 'initial' visibility is applied only once.
